@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2009 Pawel Stolowski <pawel.stolowski@wp.pl>
+ * Copyright (C) 2005-2010 Pawel Stolowski <stolowski@gmail.com>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,6 +15,7 @@
 #include "PageViewBase.h"
 #include <QColorDialog>
 #include <QFontDialog>
+#include <QFileDialog>
 
 using namespace QComicBook;
 
@@ -33,9 +34,7 @@ ComicBookCfgDialog::ComicBookCfgDialog(QWidget *parent, ComicBookSettings *cfg):
 
     //
     // background color
-    QPalette palette;
-    palette.setColor(pb_color->backgroundRole(), bgcolor = cfg->background());
-    pb_color->setPalette(palette);
+    pb_color->setColor(cfg->background());
     
     connect(pb_color, SIGNAL(clicked()), this, SLOT(showBackgroundDialog()));
 
@@ -55,6 +54,8 @@ ComicBookCfgDialog::ComicBookCfgDialog(QWidget *parent, ComicBookSettings *cfg):
     sb_thumbsage->setValue(cfg->thumbnailsAge());
     cb_splash->setChecked(cfg->showSplash());
     cb_confirmexit->setChecked(cfg->confirmExit());
+    le_tempdir->setText(cfg->tmpDir());
+    connect(b_browsetemp, SIGNAL(clicked()), this, SLOT(showTempDirDialog()));
 }
 
 ComicBookCfgDialog::~ComicBookCfgDialog()
@@ -65,12 +66,12 @@ void ComicBookCfgDialog::accept()
 {
 	//
 	// display
-	cfg->background(bgcolor);
+	cfg->background(pb_color->getColor());
 	cfg->fullScreenHideMenu(cb_hidemenu->isChecked());
 	cfg->fullScreenHideStatusbar(cb_hidestatus->isChecked());
 	cfg->fullScreenHideToolbar(cb_hidetoolbar->isChecked());
 	cfg->smallCursor(cb_smallcursor->isChecked());
-        cfg->embedPageNumbers(cb_embedpagenumbers->isChecked());
+	cfg->embedPageNumbers(cb_embedpagenumbers->isChecked());
 	cfg->smoothScaling(cb_smoothscaling->isChecked());
 	cfg->infoFont(font);
 
@@ -84,6 +85,7 @@ void ComicBookCfgDialog::accept()
 	cfg->autoInfo(cb_autoinfo->isChecked());
 	cfg->showSplash(cb_splash->isChecked());
 	cfg->confirmExit(cb_confirmexit->isChecked());
+        cfg->tmpDir(le_tempdir->text());
 
         emit displaySettingsChanged(); //FIXME only if needed
 	QDialog::accept();
@@ -100,9 +102,7 @@ void ComicBookCfgDialog::showBackgroundDialog()
 	QColor c = QColorDialog::getColor(cfg->background(), this);
 	if (c.isValid())
 	{
-		QPalette palette;
-		palette.setColor(pb_color->backgroundRole(), bgcolor = c);
-		pb_color->setPalette(palette);
+		pb_color->setColor(c);
 	}
 }
 
@@ -113,3 +113,12 @@ void ComicBookCfgDialog::showFontDialog()
 	if (ok)
 		updateFontPreview();
 }
+
+void ComicBookCfgDialog::showTempDirDialog()
+{
+    QString dir(QFileDialog::getExistingDirectory(this, tr("Choose temporary directory"), le_tempdir->text()));
+    if (!(dir.isNull() || dir.isEmpty()))
+    {
+        le_tempdir->setText(dir);
+    }
+}
