@@ -17,15 +17,16 @@
 
 class QLabel;
 class QProgressBar;
-class QImage;
 
 namespace QComicBook
 {
-	class StatusBar: public QStatusBar
-	{
-		Q_OBJECT
+    class Page;
 
-		private:
+    class StatusBar: public QStatusBar
+    {
+        Q_OBJECT
+            
+            private:
 			QLabel *page;
 			QLabel *imginfo;
 			QLabel *name;
@@ -34,7 +35,7 @@ namespace QComicBook
 		public slots:
 			void setPage(int n, int total);
 			void setName(const QString &n);
-			void setImageInfo(const QImage *img1, const QImage *img2=NULL);
+			void setImageInfo(const Page *img1, const Page *img2 = NULL);
 			void setProgress(int n, int total);
 			void clear();
 
