@@ -19,6 +19,7 @@
 #include <QLocale>
 #include "ComicMainWindow.h"
 #include "ComicBookSettings.h"
+#include <ComicFrameList.h>
 #include "Thumbnail.h"
 #include "Page.h"
 #include "config.h"
@@ -46,6 +47,7 @@ int main(int argc, char *argv[])
 
         qRegisterMetaType<Page>("Page");
         qRegisterMetaType<Thumbnail>("Thumbnail");
+		qRegisterMetaType<ComicFrameList>("ComicFrameList");
 
 	ComicBookSettings::instance().load();
 
@@ -82,9 +84,16 @@ int main(int argc, char *argv[])
 	//
 	// command line argument
 	if (app.argc() > 1)
-        { 
-            win->open(QString::fromLocal8Bit(app.argv()[1]));
-        }
+	{ 
+		win->open(QString::fromLocal8Bit(app.argv()[1]));
+	}
+	else
+	{
+		if (ComicBookSettings::instance().showDonationDialog())
+		{
+			win->showAboutDonating(true);
+		}
+	}
 
 	return app.exec();
 }
